# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/universe/universe.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from eolymp.universe import space_pb2 as eolymp_dot_universe_dot_space__pb2
from eolymp.universe import member_pb2 as eolymp_dot_universe_dot_member__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/universe/universe.proto',
  package='eolymp.universe',
  syntax='proto3',
  serialized_options=b'Z7github.com/eolymp/contracts/go/eolymp/universe;universe',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x65olymp/universe/universe.proto\x12\x0f\x65olymp.universe\x1a\x1d\x65olymp/annotations/http.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1b\x65olymp/universe/space.proto\x1a\x1c\x65olymp/universe/member.proto\"9\n\x10\x43reateSpaceInput\x12%\n\x05space\x18\x01 \x01(\x0b\x32\x16.eolymp.universe.Space\"%\n\x11\x43reateSpaceOutput\x12\x10\n\x08space_id\x18\x01 \x01(\t\"K\n\x10UpdateSpaceInput\x12\x10\n\x08space_id\x18\x01 \x01(\t\x12%\n\x05space\x18\x02 \x01(\x0b\x32\x16.eolymp.universe.Space\"\x13\n\x11UpdateSpaceOutput\"$\n\x10\x44\x65leteSpaceInput\x12\x10\n\x08space_id\x18\x01 \x01(\t\"\x13\n\x11\x44\x65leteSpaceOutput\"\x1f\n\x10LookupSpaceInput\x12\x0b\n\x03key\x18\x01 \x01(\t\":\n\x11LookupSpaceOutput\x12%\n\x05space\x18\x01 \x01(\x0b\x32\x16.eolymp.universe.Space\"&\n\x12\x44\x65scribeSpaceInput\x12\x10\n\x08space_id\x18\x01 \x01(\t\"<\n\x13\x44\x65scribeSpaceOutput\x12%\n\x05space\x18\x01 \x01(\x0b\x32\x16.eolymp.universe.Space\"\xff\x01\n\x0fListSpacesInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x38\n\x07\x66ilters\x18( \x01(\x0b\x32\'.eolymp.universe.ListSpacesInput.Filter\x1a\x93\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12+\n\x03key\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x03 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"H\n\x10ListSpacesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.universe.Space\"A\n\x0e\x41\x64\x64MemberInput\x12\x10\n\x08space_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x0c\n\x04role\x18\x03 \x01(\t\"$\n\x0f\x41\x64\x64MemberOutput\x12\x11\n\tmember_id\x18\x01 \x01(\t\"4\n\x11UpdateMemberInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\t\"\x14\n\x12UpdateMemberOutput\"&\n\x11RemoveMemberInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\"\x14\n\x12RemoveMemberOutput\"(\n\x13\x44\x65scribeMemberInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\"?\n\x14\x44\x65scribeMemberOutput\x12\'\n\x06member\x18\x01 \x01(\x0b\x32\x17.eolymp.universe.Member\")\n\x15IntrospectMemberInput\x12\x10\n\x08space_id\x18\x01 \x01(\t\"A\n\x16IntrospectMemberOutput\x12\'\n\x06member\x18\x01 \x01(\x0b\x32\x17.eolymp.universe.Member\"\xcb\x02\n\x10ListMembersInput\x12\x10\n\x08space_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x39\n\x07\x66ilters\x18( \x01(\x0b\x32(.eolymp.universe.ListMembersInput.Filter\x1a\xcb\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07user_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12.\n\x04role\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x34\n\x08username\x18\x04 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"J\n\x11ListMembersOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.universe.Member2\x9e\x10\n\x08Universe\x12\x9c\x01\n\x0b\x43reateSpace\x12!.eolymp.universe.CreateSpaceInput\x1a\".eolymp.universe.CreateSpaceOutput\"F\x82\xe3\n\x18\x8a\xe3\n\x14universe:space:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x15\"\x10/universe/spacesb\x01*\x12\xa4\x01\n\x0bUpdateSpace\x12!.eolymp.universe.UpdateSpaceInput\x1a\".eolymp.universe.UpdateSpaceOutput\"N\x82\xe3\n\x18\x8a\xe3\n\x14universe:space:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1d\x1a\x1b/universe/spaces/{space_id}\x12\xa4\x01\n\x0b\x44\x65leteSpace\x12!.eolymp.universe.DeleteSpaceInput\x1a\".eolymp.universe.DeleteSpaceOutput\"N\x82\xe3\n\x18\x8a\xe3\n\x14universe:space:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x1d*\x1b/universe/spaces/{space_id}\x12\x90\x01\n\x0bLookupSpace\x12!.eolymp.universe.LookupSpaceInput\x1a\".eolymp.universe.LookupSpaceOutput\":\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02%\x12\x1c/universe/space-lookup/{key}b\x05space\x12\xb0\x01\n\rDescribeSpace\x12#.eolymp.universe.DescribeSpaceInput\x1a$.eolymp.universe.DescribeSpaceOutput\"T\x82\xe3\n\x17\x8a\xe3\n\x13universe:space:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02$\x12\x1b/universe/spaces/{space_id}b\x05space\x12\x98\x01\n\nListSpaces\x12 .eolymp.universe.ListSpacesInput\x1a!.eolymp.universe.ListSpacesOutput\"E\x82\xe3\n\x17\x8a\xe3\n\x13universe:space:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x15\x12\x10/universe/spacesb\x01*\x12\xb3\x01\n\tAddMember\x12\x1f.eolymp.universe.AddMemberInput\x1a .eolymp.universe.AddMemberOutput\"c\x82\xe3\n\x18\x8a\xe3\n\x14universe:space:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x32\x1a-/universe/spaces/{space_id}/members/{user_id}b\x01*\x12\xac\x01\n\x0cUpdateMember\x12\".eolymp.universe.UpdateMemberInput\x1a#.eolymp.universe.UpdateMemberOutput\"S\x82\xe3\n\x18\x8a\xe3\n\x14universe:space:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\"\x1a\x1d/universe/members/{member_id}b\x01*\x12\xac\x01\n\x0cRemoveMember\x12\".eolymp.universe.RemoveMemberInput\x1a#.eolymp.universe.RemoveMemberOutput\"S\x82\xe3\n\x18\x8a\xe3\n\x14universe:space:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\"*\x1d/universe/members/{member_id}b\x01*\x12\xb6\x01\n\x0e\x44\x65scribeMember\x12$.eolymp.universe.DescribeMemberInput\x1a%.eolymp.universe.DescribeMemberOutput\"W\x82\xe3\n\x17\x8a\xe3\n\x13universe:space:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\'\x12\x1d/universe/members/{member_id}b\x06member\x12\xc5\x01\n\x10IntrospectMember\x12&.eolymp.universe.IntrospectMemberInput\x1a\'.eolymp.universe.IntrospectMemberOutput\"`\x82\xe3\n\x17\x8a\xe3\n\x13universe:space:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x30\x12&/universe/spaces/{space_id}/introspectb\x06member\x12\xae\x01\n\x0bListMembers\x12!.eolymp.universe.ListMembersInput\x1a\".eolymp.universe.ListMembersOutput\"X\x82\xe3\n\x17\x8a\xe3\n\x13universe:space:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02(\x12#/universe/spaces/{space_id}/membersb\x01*B9Z7github.com/eolymp/contracts/go/eolymp/universe;universeb\x06proto3'
  ,
  dependencies=[eolymp_dot_annotations_dot_http__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_scope__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_ratelimit__pb2.DESCRIPTOR,eolymp_dot_wellknown_dot_expression__pb2.DESCRIPTOR,eolymp_dot_universe_dot_space__pb2.DESCRIPTOR,eolymp_dot_universe_dot_member__pb2.DESCRIPTOR,])




_CREATESPACEINPUT = _descriptor.Descriptor(
  name='CreateSpaceInput',
  full_name='eolymp.universe.CreateSpaceInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space', full_name='eolymp.universe.CreateSpaceInput.space', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=244,
  serialized_end=301,
)


_CREATESPACEOUTPUT = _descriptor.Descriptor(
  name='CreateSpaceOutput',
  full_name='eolymp.universe.CreateSpaceOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='eolymp.universe.CreateSpaceOutput.space_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=303,
  serialized_end=340,
)


_UPDATESPACEINPUT = _descriptor.Descriptor(
  name='UpdateSpaceInput',
  full_name='eolymp.universe.UpdateSpaceInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='eolymp.universe.UpdateSpaceInput.space_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='space', full_name='eolymp.universe.UpdateSpaceInput.space', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=342,
  serialized_end=417,
)


_UPDATESPACEOUTPUT = _descriptor.Descriptor(
  name='UpdateSpaceOutput',
  full_name='eolymp.universe.UpdateSpaceOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=419,
  serialized_end=438,
)


_DELETESPACEINPUT = _descriptor.Descriptor(
  name='DeleteSpaceInput',
  full_name='eolymp.universe.DeleteSpaceInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='eolymp.universe.DeleteSpaceInput.space_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=440,
  serialized_end=476,
)


_DELETESPACEOUTPUT = _descriptor.Descriptor(
  name='DeleteSpaceOutput',
  full_name='eolymp.universe.DeleteSpaceOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=478,
  serialized_end=497,
)


_LOOKUPSPACEINPUT = _descriptor.Descriptor(
  name='LookupSpaceInput',
  full_name='eolymp.universe.LookupSpaceInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='eolymp.universe.LookupSpaceInput.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=499,
  serialized_end=530,
)


_LOOKUPSPACEOUTPUT = _descriptor.Descriptor(
  name='LookupSpaceOutput',
  full_name='eolymp.universe.LookupSpaceOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space', full_name='eolymp.universe.LookupSpaceOutput.space', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=532,
  serialized_end=590,
)


_DESCRIBESPACEINPUT = _descriptor.Descriptor(
  name='DescribeSpaceInput',
  full_name='eolymp.universe.DescribeSpaceInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='eolymp.universe.DescribeSpaceInput.space_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=592,
  serialized_end=630,
)


_DESCRIBESPACEOUTPUT = _descriptor.Descriptor(
  name='DescribeSpaceOutput',
  full_name='eolymp.universe.DescribeSpaceOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space', full_name='eolymp.universe.DescribeSpaceOutput.space', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=632,
  serialized_end=692,
)


_LISTSPACESINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.universe.ListSpacesInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.universe.ListSpacesInput.Filter.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='eolymp.universe.ListSpacesInput.Filter.key', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='eolymp.universe.ListSpacesInput.Filter.name', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=803,
  serialized_end=950,
)

_LISTSPACESINPUT = _descriptor.Descriptor(
  name='ListSpacesInput',
  full_name='eolymp.universe.ListSpacesInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.universe.ListSpacesInput.offset', index=0,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.universe.ListSpacesInput.size', index=1,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.universe.ListSpacesInput.filters', index=2,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTSPACESINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=695,
  serialized_end=950,
)


_LISTSPACESOUTPUT = _descriptor.Descriptor(
  name='ListSpacesOutput',
  full_name='eolymp.universe.ListSpacesOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.universe.ListSpacesOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.universe.ListSpacesOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=952,
  serialized_end=1024,
)


_ADDMEMBERINPUT = _descriptor.Descriptor(
  name='AddMemberInput',
  full_name='eolymp.universe.AddMemberInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='eolymp.universe.AddMemberInput.space_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.universe.AddMemberInput.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role', full_name='eolymp.universe.AddMemberInput.role', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1026,
  serialized_end=1091,
)


_ADDMEMBEROUTPUT = _descriptor.Descriptor(
  name='AddMemberOutput',
  full_name='eolymp.universe.AddMemberOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member_id', full_name='eolymp.universe.AddMemberOutput.member_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1093,
  serialized_end=1129,
)


_UPDATEMEMBERINPUT = _descriptor.Descriptor(
  name='UpdateMemberInput',
  full_name='eolymp.universe.UpdateMemberInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member_id', full_name='eolymp.universe.UpdateMemberInput.member_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role', full_name='eolymp.universe.UpdateMemberInput.role', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1131,
  serialized_end=1183,
)


_UPDATEMEMBEROUTPUT = _descriptor.Descriptor(
  name='UpdateMemberOutput',
  full_name='eolymp.universe.UpdateMemberOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1185,
  serialized_end=1205,
)


_REMOVEMEMBERINPUT = _descriptor.Descriptor(
  name='RemoveMemberInput',
  full_name='eolymp.universe.RemoveMemberInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member_id', full_name='eolymp.universe.RemoveMemberInput.member_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1207,
  serialized_end=1245,
)


_REMOVEMEMBEROUTPUT = _descriptor.Descriptor(
  name='RemoveMemberOutput',
  full_name='eolymp.universe.RemoveMemberOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1247,
  serialized_end=1267,
)


_DESCRIBEMEMBERINPUT = _descriptor.Descriptor(
  name='DescribeMemberInput',
  full_name='eolymp.universe.DescribeMemberInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member_id', full_name='eolymp.universe.DescribeMemberInput.member_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1269,
  serialized_end=1309,
)


_DESCRIBEMEMBEROUTPUT = _descriptor.Descriptor(
  name='DescribeMemberOutput',
  full_name='eolymp.universe.DescribeMemberOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member', full_name='eolymp.universe.DescribeMemberOutput.member', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1311,
  serialized_end=1374,
)


_INTROSPECTMEMBERINPUT = _descriptor.Descriptor(
  name='IntrospectMemberInput',
  full_name='eolymp.universe.IntrospectMemberInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='eolymp.universe.IntrospectMemberInput.space_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1376,
  serialized_end=1417,
)


_INTROSPECTMEMBEROUTPUT = _descriptor.Descriptor(
  name='IntrospectMemberOutput',
  full_name='eolymp.universe.IntrospectMemberOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member', full_name='eolymp.universe.IntrospectMemberOutput.member', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1419,
  serialized_end=1484,
)


_LISTMEMBERSINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.universe.ListMembersInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.universe.ListMembersInput.Filter.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.universe.ListMembersInput.Filter.user_id', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role', full_name='eolymp.universe.ListMembersInput.Filter.role', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='username', full_name='eolymp.universe.ListMembersInput.Filter.username', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1615,
  serialized_end=1818,
)

_LISTMEMBERSINPUT = _descriptor.Descriptor(
  name='ListMembersInput',
  full_name='eolymp.universe.ListMembersInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='eolymp.universe.ListMembersInput.space_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.universe.ListMembersInput.offset', index=1,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.universe.ListMembersInput.size', index=2,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.universe.ListMembersInput.filters', index=3,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTMEMBERSINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1487,
  serialized_end=1818,
)


_LISTMEMBERSOUTPUT = _descriptor.Descriptor(
  name='ListMembersOutput',
  full_name='eolymp.universe.ListMembersOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.universe.ListMembersOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.universe.ListMembersOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1820,
  serialized_end=1894,
)

_CREATESPACEINPUT.fields_by_name['space'].message_type = eolymp_dot_universe_dot_space__pb2._SPACE
_UPDATESPACEINPUT.fields_by_name['space'].message_type = eolymp_dot_universe_dot_space__pb2._SPACE
_LOOKUPSPACEOUTPUT.fields_by_name['space'].message_type = eolymp_dot_universe_dot_space__pb2._SPACE
_DESCRIBESPACEOUTPUT.fields_by_name['space'].message_type = eolymp_dot_universe_dot_space__pb2._SPACE
_LISTSPACESINPUT_FILTER.fields_by_name['id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTSPACESINPUT_FILTER.fields_by_name['key'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTSPACESINPUT_FILTER.fields_by_name['name'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONSTRING
_LISTSPACESINPUT_FILTER.containing_type = _LISTSPACESINPUT
_LISTSPACESINPUT.fields_by_name['filters'].message_type = _LISTSPACESINPUT_FILTER
_LISTSPACESOUTPUT.fields_by_name['items'].message_type = eolymp_dot_universe_dot_space__pb2._SPACE
_DESCRIBEMEMBEROUTPUT.fields_by_name['member'].message_type = eolymp_dot_universe_dot_member__pb2._MEMBER
_INTROSPECTMEMBEROUTPUT.fields_by_name['member'].message_type = eolymp_dot_universe_dot_member__pb2._MEMBER
_LISTMEMBERSINPUT_FILTER.fields_by_name['id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTMEMBERSINPUT_FILTER.fields_by_name['user_id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTMEMBERSINPUT_FILTER.fields_by_name['role'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONENUM
_LISTMEMBERSINPUT_FILTER.fields_by_name['username'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONSTRING
_LISTMEMBERSINPUT_FILTER.containing_type = _LISTMEMBERSINPUT
_LISTMEMBERSINPUT.fields_by_name['filters'].message_type = _LISTMEMBERSINPUT_FILTER
_LISTMEMBERSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_universe_dot_member__pb2._MEMBER
DESCRIPTOR.message_types_by_name['CreateSpaceInput'] = _CREATESPACEINPUT
DESCRIPTOR.message_types_by_name['CreateSpaceOutput'] = _CREATESPACEOUTPUT
DESCRIPTOR.message_types_by_name['UpdateSpaceInput'] = _UPDATESPACEINPUT
DESCRIPTOR.message_types_by_name['UpdateSpaceOutput'] = _UPDATESPACEOUTPUT
DESCRIPTOR.message_types_by_name['DeleteSpaceInput'] = _DELETESPACEINPUT
DESCRIPTOR.message_types_by_name['DeleteSpaceOutput'] = _DELETESPACEOUTPUT
DESCRIPTOR.message_types_by_name['LookupSpaceInput'] = _LOOKUPSPACEINPUT
DESCRIPTOR.message_types_by_name['LookupSpaceOutput'] = _LOOKUPSPACEOUTPUT
DESCRIPTOR.message_types_by_name['DescribeSpaceInput'] = _DESCRIBESPACEINPUT
DESCRIPTOR.message_types_by_name['DescribeSpaceOutput'] = _DESCRIBESPACEOUTPUT
DESCRIPTOR.message_types_by_name['ListSpacesInput'] = _LISTSPACESINPUT
DESCRIPTOR.message_types_by_name['ListSpacesOutput'] = _LISTSPACESOUTPUT
DESCRIPTOR.message_types_by_name['AddMemberInput'] = _ADDMEMBERINPUT
DESCRIPTOR.message_types_by_name['AddMemberOutput'] = _ADDMEMBEROUTPUT
DESCRIPTOR.message_types_by_name['UpdateMemberInput'] = _UPDATEMEMBERINPUT
DESCRIPTOR.message_types_by_name['UpdateMemberOutput'] = _UPDATEMEMBEROUTPUT
DESCRIPTOR.message_types_by_name['RemoveMemberInput'] = _REMOVEMEMBERINPUT
DESCRIPTOR.message_types_by_name['RemoveMemberOutput'] = _REMOVEMEMBEROUTPUT
DESCRIPTOR.message_types_by_name['DescribeMemberInput'] = _DESCRIBEMEMBERINPUT
DESCRIPTOR.message_types_by_name['DescribeMemberOutput'] = _DESCRIBEMEMBEROUTPUT
DESCRIPTOR.message_types_by_name['IntrospectMemberInput'] = _INTROSPECTMEMBERINPUT
DESCRIPTOR.message_types_by_name['IntrospectMemberOutput'] = _INTROSPECTMEMBEROUTPUT
DESCRIPTOR.message_types_by_name['ListMembersInput'] = _LISTMEMBERSINPUT
DESCRIPTOR.message_types_by_name['ListMembersOutput'] = _LISTMEMBERSOUTPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateSpaceInput = _reflection.GeneratedProtocolMessageType('CreateSpaceInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATESPACEINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.CreateSpaceInput)
  })
_sym_db.RegisterMessage(CreateSpaceInput)

CreateSpaceOutput = _reflection.GeneratedProtocolMessageType('CreateSpaceOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATESPACEOUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.CreateSpaceOutput)
  })
_sym_db.RegisterMessage(CreateSpaceOutput)

UpdateSpaceInput = _reflection.GeneratedProtocolMessageType('UpdateSpaceInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESPACEINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.UpdateSpaceInput)
  })
_sym_db.RegisterMessage(UpdateSpaceInput)

UpdateSpaceOutput = _reflection.GeneratedProtocolMessageType('UpdateSpaceOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESPACEOUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.UpdateSpaceOutput)
  })
_sym_db.RegisterMessage(UpdateSpaceOutput)

DeleteSpaceInput = _reflection.GeneratedProtocolMessageType('DeleteSpaceInput', (_message.Message,), {
  'DESCRIPTOR' : _DELETESPACEINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.DeleteSpaceInput)
  })
_sym_db.RegisterMessage(DeleteSpaceInput)

DeleteSpaceOutput = _reflection.GeneratedProtocolMessageType('DeleteSpaceOutput', (_message.Message,), {
  'DESCRIPTOR' : _DELETESPACEOUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.DeleteSpaceOutput)
  })
_sym_db.RegisterMessage(DeleteSpaceOutput)

LookupSpaceInput = _reflection.GeneratedProtocolMessageType('LookupSpaceInput', (_message.Message,), {
  'DESCRIPTOR' : _LOOKUPSPACEINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.LookupSpaceInput)
  })
_sym_db.RegisterMessage(LookupSpaceInput)

LookupSpaceOutput = _reflection.GeneratedProtocolMessageType('LookupSpaceOutput', (_message.Message,), {
  'DESCRIPTOR' : _LOOKUPSPACEOUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.LookupSpaceOutput)
  })
_sym_db.RegisterMessage(LookupSpaceOutput)

DescribeSpaceInput = _reflection.GeneratedProtocolMessageType('DescribeSpaceInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESPACEINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.DescribeSpaceInput)
  })
_sym_db.RegisterMessage(DescribeSpaceInput)

DescribeSpaceOutput = _reflection.GeneratedProtocolMessageType('DescribeSpaceOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESPACEOUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.DescribeSpaceOutput)
  })
_sym_db.RegisterMessage(DescribeSpaceOutput)

ListSpacesInput = _reflection.GeneratedProtocolMessageType('ListSpacesInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTSPACESINPUT_FILTER,
    '__module__' : 'eolymp.universe.universe_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.universe.ListSpacesInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTSPACESINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.ListSpacesInput)
  })
_sym_db.RegisterMessage(ListSpacesInput)
_sym_db.RegisterMessage(ListSpacesInput.Filter)

ListSpacesOutput = _reflection.GeneratedProtocolMessageType('ListSpacesOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTSPACESOUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.ListSpacesOutput)
  })
_sym_db.RegisterMessage(ListSpacesOutput)

AddMemberInput = _reflection.GeneratedProtocolMessageType('AddMemberInput', (_message.Message,), {
  'DESCRIPTOR' : _ADDMEMBERINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.AddMemberInput)
  })
_sym_db.RegisterMessage(AddMemberInput)

AddMemberOutput = _reflection.GeneratedProtocolMessageType('AddMemberOutput', (_message.Message,), {
  'DESCRIPTOR' : _ADDMEMBEROUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.AddMemberOutput)
  })
_sym_db.RegisterMessage(AddMemberOutput)

UpdateMemberInput = _reflection.GeneratedProtocolMessageType('UpdateMemberInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMEMBERINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.UpdateMemberInput)
  })
_sym_db.RegisterMessage(UpdateMemberInput)

UpdateMemberOutput = _reflection.GeneratedProtocolMessageType('UpdateMemberOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMEMBEROUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.UpdateMemberOutput)
  })
_sym_db.RegisterMessage(UpdateMemberOutput)

RemoveMemberInput = _reflection.GeneratedProtocolMessageType('RemoveMemberInput', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEMEMBERINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.RemoveMemberInput)
  })
_sym_db.RegisterMessage(RemoveMemberInput)

RemoveMemberOutput = _reflection.GeneratedProtocolMessageType('RemoveMemberOutput', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEMEMBEROUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.RemoveMemberOutput)
  })
_sym_db.RegisterMessage(RemoveMemberOutput)

DescribeMemberInput = _reflection.GeneratedProtocolMessageType('DescribeMemberInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEMEMBERINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.DescribeMemberInput)
  })
_sym_db.RegisterMessage(DescribeMemberInput)

DescribeMemberOutput = _reflection.GeneratedProtocolMessageType('DescribeMemberOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEMEMBEROUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.DescribeMemberOutput)
  })
_sym_db.RegisterMessage(DescribeMemberOutput)

IntrospectMemberInput = _reflection.GeneratedProtocolMessageType('IntrospectMemberInput', (_message.Message,), {
  'DESCRIPTOR' : _INTROSPECTMEMBERINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.IntrospectMemberInput)
  })
_sym_db.RegisterMessage(IntrospectMemberInput)

IntrospectMemberOutput = _reflection.GeneratedProtocolMessageType('IntrospectMemberOutput', (_message.Message,), {
  'DESCRIPTOR' : _INTROSPECTMEMBEROUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.IntrospectMemberOutput)
  })
_sym_db.RegisterMessage(IntrospectMemberOutput)

ListMembersInput = _reflection.GeneratedProtocolMessageType('ListMembersInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTMEMBERSINPUT_FILTER,
    '__module__' : 'eolymp.universe.universe_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.universe.ListMembersInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTMEMBERSINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.ListMembersInput)
  })
_sym_db.RegisterMessage(ListMembersInput)
_sym_db.RegisterMessage(ListMembersInput.Filter)

ListMembersOutput = _reflection.GeneratedProtocolMessageType('ListMembersOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTMEMBERSOUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.ListMembersOutput)
  })
_sym_db.RegisterMessage(ListMembersOutput)


DESCRIPTOR._options = None

_UNIVERSE = _descriptor.ServiceDescriptor(
  name='Universe',
  full_name='eolymp.universe.Universe',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1897,
  serialized_end=3975,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateSpace',
    full_name='eolymp.universe.Universe.CreateSpace',
    index=0,
    containing_service=None,
    input_type=_CREATESPACEINPUT,
    output_type=_CREATESPACEOUTPUT,
    serialized_options=b'\202\343\n\030\212\343\n\024universe:space:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\025\"\020/universe/spacesb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateSpace',
    full_name='eolymp.universe.Universe.UpdateSpace',
    index=1,
    containing_service=None,
    input_type=_UPDATESPACEINPUT,
    output_type=_UPDATESPACEOUTPUT,
    serialized_options=b'\202\343\n\030\212\343\n\024universe:space:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\035\032\033/universe/spaces/{space_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteSpace',
    full_name='eolymp.universe.Universe.DeleteSpace',
    index=2,
    containing_service=None,
    input_type=_DELETESPACEINPUT,
    output_type=_DELETESPACEOUTPUT,
    serialized_options=b'\202\343\n\030\212\343\n\024universe:space:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\035*\033/universe/spaces/{space_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LookupSpace',
    full_name='eolymp.universe.Universe.LookupSpace',
    index=3,
    containing_service=None,
    input_type=_LOOKUPSPACEINPUT,
    output_type=_LOOKUPSPACEOUTPUT,
    serialized_options=b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002%\022\034/universe/space-lookup/{key}b\005space',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeSpace',
    full_name='eolymp.universe.Universe.DescribeSpace',
    index=4,
    containing_service=None,
    input_type=_DESCRIBESPACEINPUT,
    output_type=_DESCRIBESPACEOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023universe:space:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002$\022\033/universe/spaces/{space_id}b\005space',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListSpaces',
    full_name='eolymp.universe.Universe.ListSpaces',
    index=5,
    containing_service=None,
    input_type=_LISTSPACESINPUT,
    output_type=_LISTSPACESOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023universe:space:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\025\022\020/universe/spacesb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddMember',
    full_name='eolymp.universe.Universe.AddMember',
    index=6,
    containing_service=None,
    input_type=_ADDMEMBERINPUT,
    output_type=_ADDMEMBEROUTPUT,
    serialized_options=b'\202\343\n\030\212\343\n\024universe:space:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\0022\032-/universe/spaces/{space_id}/members/{user_id}b\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateMember',
    full_name='eolymp.universe.Universe.UpdateMember',
    index=7,
    containing_service=None,
    input_type=_UPDATEMEMBERINPUT,
    output_type=_UPDATEMEMBEROUTPUT,
    serialized_options=b'\202\343\n\030\212\343\n\024universe:space:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\"\032\035/universe/members/{member_id}b\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveMember',
    full_name='eolymp.universe.Universe.RemoveMember',
    index=8,
    containing_service=None,
    input_type=_REMOVEMEMBERINPUT,
    output_type=_REMOVEMEMBEROUTPUT,
    serialized_options=b'\202\343\n\030\212\343\n\024universe:space:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\"*\035/universe/members/{member_id}b\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeMember',
    full_name='eolymp.universe.Universe.DescribeMember',
    index=9,
    containing_service=None,
    input_type=_DESCRIBEMEMBERINPUT,
    output_type=_DESCRIBEMEMBEROUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023universe:space:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\'\022\035/universe/members/{member_id}b\006member',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='IntrospectMember',
    full_name='eolymp.universe.Universe.IntrospectMember',
    index=10,
    containing_service=None,
    input_type=_INTROSPECTMEMBERINPUT,
    output_type=_INTROSPECTMEMBEROUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023universe:space:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\0020\022&/universe/spaces/{space_id}/introspectb\006member',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListMembers',
    full_name='eolymp.universe.Universe.ListMembers',
    index=11,
    containing_service=None,
    input_type=_LISTMEMBERSINPUT,
    output_type=_LISTMEMBERSOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023universe:space:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002(\022#/universe/spaces/{space_id}/membersb\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_UNIVERSE)

DESCRIPTOR.services_by_name['Universe'] = _UNIVERSE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/activity.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/judge/activity.proto',
  package='eolymp.judge',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/judge;judge',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1b\x65olymp/judge/activity.proto\x12\x0c\x65olymp.judge\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa9\x04\n\x08\x41\x63tivity\x12\n\n\x02id\x18\x01 \x01(\t\x12)\n\x04type\x18\x02 \x01(\x0e\x32\x1b.eolymp.judge.Activity.Type\x12-\n\x06status\x18\x03 \x01(\x0e\x32\x1d.eolymp.judge.Activity.Status\x12\x12\n\ncontest_id\x18\x05 \x01(\t\x12\x15\n\rscoreboard_id\x18\x64 \x01(\t\x12\x12\n\nproblem_id\x18\x65 \x01(\t\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bprogress_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x63omplete_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08progress\x18\x14 \x01(\r\x12\r\n\x05total\x18\x15 \x01(\r\x12\r\n\x05\x65rror\x18\x1e \x01(\t\"<\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\x12\n\x0ePROBLEM_RETEST\x10\x01\x12\x16\n\x12SCOREBOARD_REBUILD\x10\x02\"H\n\x06Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0b\n\x07STARTED\x10\x02\x12\x0c\n\x08\x43OMPLETE\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x42\x33Z1github.com/eolymp/contracts/go/eolymp/judge;judgeb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_ACTIVITY_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='eolymp.judge.Activity.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROBLEM_RETEST', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCOREBOARD_REBUILD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=498,
  serialized_end=558,
)
_sym_db.RegisterEnumDescriptor(_ACTIVITY_TYPE)

_ACTIVITY_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='eolymp.judge.Activity.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STARTED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPLETE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=560,
  serialized_end=632,
)
_sym_db.RegisterEnumDescriptor(_ACTIVITY_STATUS)


_ACTIVITY = _descriptor.Descriptor(
  name='Activity',
  full_name='eolymp.judge.Activity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.judge.Activity.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='eolymp.judge.Activity.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='eolymp.judge.Activity.status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.Activity.contest_id', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.judge.Activity.scoreboard_id', index=4,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.judge.Activity.problem_id', index=5,
      number=101, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='eolymp.judge.Activity.created_at', index=6,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='started_at', full_name='eolymp.judge.Activity.started_at', index=7,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='progress_at', full_name='eolymp.judge.Activity.progress_at', index=8,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='complete_at', full_name='eolymp.judge.Activity.complete_at', index=9,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='progress', full_name='eolymp.judge.Activity.progress', index=10,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.judge.Activity.total', index=11,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='eolymp.judge.Activity.error', index=12,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ACTIVITY_TYPE,
    _ACTIVITY_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=632,
)

_ACTIVITY.fields_by_name['type'].enum_type = _ACTIVITY_TYPE
_ACTIVITY.fields_by_name['status'].enum_type = _ACTIVITY_STATUS
_ACTIVITY.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ACTIVITY.fields_by_name['started_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ACTIVITY.fields_by_name['progress_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ACTIVITY.fields_by_name['complete_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ACTIVITY_TYPE.containing_type = _ACTIVITY
_ACTIVITY_STATUS.containing_type = _ACTIVITY
DESCRIPTOR.message_types_by_name['Activity'] = _ACTIVITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Activity = _reflection.GeneratedProtocolMessageType('Activity', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITY,
  '__module__' : 'eolymp.judge.activity_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.Activity)
  })
_sym_db.RegisterMessage(Activity)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/executor/interactor.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/executor/interactor.proto',
  package='eolymp.executor',
  syntax='proto3',
  serialized_options=b'Z7github.com/eolymp/contracts/go/eolymp/executor;executor',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n eolymp/executor/interactor.proto\x12\x0f\x65olymp.executor\"y\n\nInteractor\x12.\n\x04type\x18\x01 \x01(\x0e\x32 .eolymp.executor.Interactor.Type\x12\x0c\n\x04lang\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\"\x1d\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07PROGRAM\x10\x01\x42\x39Z7github.com/eolymp/contracts/go/eolymp/executor;executorb\x06proto3'
)



_INTERACTOR_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='eolymp.executor.Interactor.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROGRAM', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=145,
  serialized_end=174,
)
_sym_db.RegisterEnumDescriptor(_INTERACTOR_TYPE)


_INTERACTOR = _descriptor.Descriptor(
  name='Interactor',
  full_name='eolymp.executor.Interactor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='eolymp.executor.Interactor.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lang', full_name='eolymp.executor.Interactor.lang', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='eolymp.executor.Interactor.source', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _INTERACTOR_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=53,
  serialized_end=174,
)

_INTERACTOR.fields_by_name['type'].enum_type = _INTERACTOR_TYPE
_INTERACTOR_TYPE.containing_type = _INTERACTOR
DESCRIPTOR.message_types_by_name['Interactor'] = _INTERACTOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Interactor = _reflection.GeneratedProtocolMessageType('Interactor', (_message.Message,), {
  'DESCRIPTOR' : _INTERACTOR,
  '__module__' : 'eolymp.executor.interactor_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.Interactor)
  })
_sym_db.RegisterMessage(Interactor)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/executor/task.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.executor import interactor_pb2 as eolymp_dot_executor_dot_interactor__pb2
from eolymp.executor import verifier_pb2 as eolymp_dot_executor_dot_verifier__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/executor/task.proto',
  package='eolymp.executor',
  syntax='proto3',
  serialized_options=b'Z7github.com/eolymp/contracts/go/eolymp/executor;executor',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x65olymp/executor/task.proto\x12\x0f\x65olymp.executor\x1a eolymp/executor/interactor.proto\x1a\x1e\x65olymp/executor/verifier.proto\"\xdb\x06\n\x04Task\x12\x11\n\treference\x18\x01 \x01(\t\x12\x0e\n\x06origin\x18\x02 \x01(\t\x12\x10\n\x08priority\x18\x03 \x01(\r\x12\r\n\x04lang\x18\xe8\x07 \x01(\t\x12\x0f\n\x07runtime\x18\n \x01(\t\x12\x0e\n\x06source\x18\x0b \x01(\t\x12\x13\n\x0buse_file_io\x18\x0c \x01(\x08\x12!\n\x19redirect_stderr_to_stdout\x18\r \x01(\x08\x12\x39\n\rpreconditions\x18( \x03(\x0b\x32\".eolymp.executor.Task.Precondition\x12\x35\n\x0b\x63onstraints\x18\x14 \x03(\x0b\x32 .eolymp.executor.Task.Constraint\x12+\n\x08verifier\x18\x18 \x01(\x0b\x32\x19.eolymp.executor.Verifier\x12/\n\ninteractor\x18\x19 \x01(\x0b\x32\x1b.eolymp.executor.Interactor\x12\'\n\x04runs\x18\x1e \x03(\x0b\x32\x19.eolymp.executor.Task.Run\x1a\xd1\x01\n\x03Run\x12\x11\n\treference\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\r\x12\r\n\x05\x64\x65\x62ug\x18\x03 \x01(\x08\x12\x0c\n\x04\x63ost\x18\x04 \x01(\x02\x12\x0e\n\x06labels\x18\x1e \x03(\t\x12\x19\n\x0finput_object_id\x18\n \x01(\tH\x00\x12\x17\n\rinput_content\x18\x0b \x01(\tH\x00\x12\x1a\n\x10\x61nswer_object_id\x18\x14 \x01(\tH\x01\x12\x18\n\x0e\x61nswer_content\x18\x15 \x01(\tH\x01\x42\x07\n\x05inputB\x08\n\x06\x61nswer\x1ai\n\x0cPrecondition\x12\x10\n\x08selector\x18\x01 \x03(\t\x12\x12\n\ndepends_on\x18\n \x03(\t\x12\x17\n\x0fstop_on_failure\x18\x0b \x01(\x08\x12\x1a\n\x12max_execution_time\x18\x0c \x01(\r\x1a~\n\nConstraint\x12\x10\n\x08selector\x18\x01 \x03(\t\x12\x17\n\x0fwall_time_limit\x18\n \x01(\r\x12\x16\n\x0e\x63pu_time_limit\x18\x0b \x01(\r\x12\x14\n\x0cmemory_limit\x18\x0c \x01(\x04\x12\x17\n\x0f\x66ile_size_limit\x18\r \x01(\x04\x42\x39Z7github.com/eolymp/contracts/go/eolymp/executor;executorb\x06proto3'
  ,
  dependencies=[eolymp_dot_executor_dot_interactor__pb2.DESCRIPTOR,eolymp_dot_executor_dot_verifier__pb2.DESCRIPTOR,])




_TASK_RUN = _descriptor.Descriptor(
  name='Run',
  full_name='eolymp.executor.Task.Run',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reference', full_name='eolymp.executor.Task.Run.reference', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='eolymp.executor.Task.Run.index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='debug', full_name='eolymp.executor.Task.Run.debug', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cost', full_name='eolymp.executor.Task.Run.cost', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='eolymp.executor.Task.Run.labels', index=4,
      number=30, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_object_id', full_name='eolymp.executor.Task.Run.input_object_id', index=5,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_content', full_name='eolymp.executor.Task.Run.input_content', index=6,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='answer_object_id', full_name='eolymp.executor.Task.Run.answer_object_id', index=7,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='answer_content', full_name='eolymp.executor.Task.Run.answer_content', index=8,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='input', full_name='eolymp.executor.Task.Run.input',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='answer', full_name='eolymp.executor.Task.Run.answer',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=529,
  serialized_end=738,
)

_TASK_PRECONDITION = _descriptor.Descriptor(
  name='Precondition',
  full_name='eolymp.executor.Task.Precondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='selector', full_name='eolymp.executor.Task.Precondition.selector', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='depends_on', full_name='eolymp.executor.Task.Precondition.depends_on', index=1,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_on_failure', full_name='eolymp.executor.Task.Precondition.stop_on_failure', index=2,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_execution_time', full_name='eolymp.executor.Task.Precondition.max_execution_time', index=3,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=740,
  serialized_end=845,
)

_TASK_CONSTRAINT = _descriptor.Descriptor(
  name='Constraint',
  full_name='eolymp.executor.Task.Constraint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='selector', full_name='eolymp.executor.Task.Constraint.selector', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wall_time_limit', full_name='eolymp.executor.Task.Constraint.wall_time_limit', index=1,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpu_time_limit', full_name='eolymp.executor.Task.Constraint.cpu_time_limit', index=2,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='memory_limit', full_name='eolymp.executor.Task.Constraint.memory_limit', index=3,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_size_limit', full_name='eolymp.executor.Task.Constraint.file_size_limit', index=4,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=847,
  serialized_end=973,
)

_TASK = _descriptor.Descriptor(
  name='Task',
  full_name='eolymp.executor.Task',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reference', full_name='eolymp.executor.Task.reference', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin', full_name='eolymp.executor.Task.origin', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='eolymp.executor.Task.priority', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lang', full_name='eolymp.executor.Task.lang', index=3,
      number=1000, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime', full_name='eolymp.executor.Task.runtime', index=4,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='eolymp.executor.Task.source', index=5,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_file_io', full_name='eolymp.executor.Task.use_file_io', index=6,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redirect_stderr_to_stdout', full_name='eolymp.executor.Task.redirect_stderr_to_stdout', index=7,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preconditions', full_name='eolymp.executor.Task.preconditions', index=8,
      number=40, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='eolymp.executor.Task.constraints', index=9,
      number=20, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='verifier', full_name='eolymp.executor.Task.verifier', index=10,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interactor', full_name='eolymp.executor.Task.interactor', index=11,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runs', full_name='eolymp.executor.Task.runs', index=12,
      number=30, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TASK_RUN, _TASK_PRECONDITION, _TASK_CONSTRAINT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=973,
)

_TASK_RUN.containing_type = _TASK
_TASK_RUN.oneofs_by_name['input'].fields.append(
  _TASK_RUN.fields_by_name['input_object_id'])
_TASK_RUN.fields_by_name['input_object_id'].containing_oneof = _TASK_RUN.oneofs_by_name['input']
_TASK_RUN.oneofs_by_name['input'].fields.append(
  _TASK_RUN.fields_by_name['input_content'])
_TASK_RUN.fields_by_name['input_content'].containing_oneof = _TASK_RUN.oneofs_by_name['input']
_TASK_RUN.oneofs_by_name['answer'].fields.append(
  _TASK_RUN.fields_by_name['answer_object_id'])
_TASK_RUN.fields_by_name['answer_object_id'].containing_oneof = _TASK_RUN.oneofs_by_name['answer']
_TASK_RUN.oneofs_by_name['answer'].fields.append(
  _TASK_RUN.fields_by_name['answer_content'])
_TASK_RUN.fields_by_name['answer_content'].containing_oneof = _TASK_RUN.oneofs_by_name['answer']
_TASK_PRECONDITION.containing_type = _TASK
_TASK_CONSTRAINT.containing_type = _TASK
_TASK.fields_by_name['preconditions'].message_type = _TASK_PRECONDITION
_TASK.fields_by_name['constraints'].message_type = _TASK_CONSTRAINT
_TASK.fields_by_name['verifier'].message_type = eolymp_dot_executor_dot_verifier__pb2._VERIFIER
_TASK.fields_by_name['interactor'].message_type = eolymp_dot_executor_dot_interactor__pb2._INTERACTOR
_TASK.fields_by_name['runs'].message_type = _TASK_RUN
DESCRIPTOR.message_types_by_name['Task'] = _TASK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Task = _reflection.GeneratedProtocolMessageType('Task', (_message.Message,), {

  'Run' : _reflection.GeneratedProtocolMessageType('Run', (_message.Message,), {
    'DESCRIPTOR' : _TASK_RUN,
    '__module__' : 'eolymp.executor.task_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.executor.Task.Run)
    })
  ,

  'Precondition' : _reflection.GeneratedProtocolMessageType('Precondition', (_message.Message,), {
    'DESCRIPTOR' : _TASK_PRECONDITION,
    '__module__' : 'eolymp.executor.task_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.executor.Task.Precondition)
    })
  ,

  'Constraint' : _reflection.GeneratedProtocolMessageType('Constraint', (_message.Message,), {
    'DESCRIPTOR' : _TASK_CONSTRAINT,
    '__module__' : 'eolymp.executor.task_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.executor.Task.Constraint)
    })
  ,
  'DESCRIPTOR' : _TASK,
  '__module__' : 'eolymp.executor.task_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.Task)
  })
_sym_db.RegisterMessage(Task)
_sym_db.RegisterMessage(Task.Run)
_sym_db.RegisterMessage(Task.Precondition)
_sym_db.RegisterMessage(Task.Constraint)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/scoring.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/atlas/scoring.proto',
  package='eolymp.atlas',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/atlas;atlas',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x65olymp/atlas/scoring.proto\x12\x0c\x65olymp.atlas*.\n\x0bScoringMode\x12\x0c\n\x08NO_SCORE\x10\x00\x12\x08\n\x04\x45\x41\x43H\x10\x01\x12\x07\n\x03\x41LL\x10\x02\x42\x33Z1github.com/eolymp/contracts/go/eolymp/atlas;atlasb\x06proto3'
)

_SCORINGMODE = _descriptor.EnumDescriptor(
  name='ScoringMode',
  full_name='eolymp.atlas.ScoringMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_SCORE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EACH', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=44,
  serialized_end=90,
)
_sym_db.RegisterEnumDescriptor(_SCORINGMODE)

ScoringMode = enum_type_wrapper.EnumTypeWrapper(_SCORINGMODE)
NO_SCORE = 0
EACH = 1
ALL = 2


DESCRIPTOR.enum_types_by_name['ScoringMode'] = _SCORINGMODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/cognito/entitlement.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/cognito/entitlement.proto',
  package='eolymp.cognito',
  syntax='proto3',
  serialized_options=b'Z5github.com/eolymp/contracts/go/eolymp/cognito;cognito',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n eolymp/cognito/entitlement.proto\x12\x0e\x65olymp.cognito*z\n\x0b\x45ntitlement\x12\x17\n\x13VIEW_PUBLIC_PROFILE\x10\x00\x12\x18\n\x14VIEW_BLOCKED_PROFILE\x10\x01\x12\x15\n\x11VIEW_PRIVATE_DATA\x10\x02\x12\x10\n\x0cMANAGE_ROLES\x10\x03\x12\x0f\n\x0b\x42LOCK_USERS\x10\x04\x42\x37Z5github.com/eolymp/contracts/go/eolymp/cognito;cognitob\x06proto3'
)

_ENTITLEMENT = _descriptor.EnumDescriptor(
  name='Entitlement',
  full_name='eolymp.cognito.Entitlement',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VIEW_PUBLIC_PROFILE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIEW_BLOCKED_PROFILE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIEW_PRIVATE_DATA', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANAGE_ROLES', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BLOCK_USERS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=52,
  serialized_end=174,
)
_sym_db.RegisterEnumDescriptor(_ENTITLEMENT)

Entitlement = enum_type_wrapper.EnumTypeWrapper(_ENTITLEMENT)
VIEW_PUBLIC_PROFILE = 0
VIEW_BLOCKED_PROFILE = 1
VIEW_PRIVATE_DATA = 2
MANAGE_ROLES = 3
BLOCK_USERS = 4


DESCRIPTOR.enum_types_by_name['Entitlement'] = _ENTITLEMENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/cognito/user.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/cognito/user.proto',
  package='eolymp.cognito',
  syntax='proto3',
  serialized_options=b'Z5github.com/eolymp/contracts/go/eolymp/cognito;cognito',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x19\x65olymp/cognito/user.proto\x12\x0e\x65olymp.cognito\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9f\x03\n\x04User\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12\x0c\n\x04rank\x18) \x01(\r\x12\x32\n\nrank_trend\x18* \x01(\x0e\x32\x1e.eolymp.cognito.User.RankTrend\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0f\n\x07picture\x18\x0b \x01(\t\x12\x0f\n\x07\x63ompany\x18\x0c \x01(\t\x12\x12\n\noccupation\x18\r \x01(\t\x12\x0f\n\x07\x63ountry\x18\x15 \x01(\t\x12\x0c\n\x04\x63ity\x18\x16 \x01(\t\x12\x14\n\x0c\x65mail_status\x18  \x01(\t\x12\x10\n\x08\x62irthday\x18! \x01(\t\x12\x31\n\rregistered_on\x18\" \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rlast_activity\x18# \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\'\n\tRankTrend\x12\x08\n\x04NONE\x10\x00\x12\x06\n\x02UP\x10\x01\x12\x08\n\x04\x44OWN\x10\x02\x42\x37Z5github.com/eolymp/contracts/go/eolymp/cognito;cognitob\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_USER_RANKTREND = _descriptor.EnumDescriptor(
  name='RankTrend',
  full_name='eolymp.cognito.User.RankTrend',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOWN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=455,
  serialized_end=494,
)
_sym_db.RegisterEnumDescriptor(_USER_RANKTREND)


_USER = _descriptor.Descriptor(
  name='User',
  full_name='eolymp.cognito.User',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.cognito.User.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='username', full_name='eolymp.cognito.User.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email', full_name='eolymp.cognito.User.email', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active', full_name='eolymp.cognito.User.active', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rank', full_name='eolymp.cognito.User.rank', index=4,
      number=41, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rank_trend', full_name='eolymp.cognito.User.rank_trend', index=5,
      number=42, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='eolymp.cognito.User.name', index=6,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='picture', full_name='eolymp.cognito.User.picture', index=7,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='company', full_name='eolymp.cognito.User.company', index=8,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='occupation', full_name='eolymp.cognito.User.occupation', index=9,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='country', full_name='eolymp.cognito.User.country', index=10,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='city', full_name='eolymp.cognito.User.city', index=11,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email_status', full_name='eolymp.cognito.User.email_status', index=12,
      number=32, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='birthday', full_name='eolymp.cognito.User.birthday', index=13,
      number=33, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='registered_on', full_name='eolymp.cognito.User.registered_on', index=14,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_activity', full_name='eolymp.cognito.User.last_activity', index=15,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _USER_RANKTREND,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=494,
)

_USER.fields_by_name['rank_trend'].enum_type = _USER_RANKTREND
_USER.fields_by_name['registered_on'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_USER.fields_by_name['last_activity'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_USER_RANKTREND.containing_type = _USER
DESCRIPTOR.message_types_by_name['User'] = _USER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

User = _reflection.GeneratedProtocolMessageType('User', (_message.Message,), {
  'DESCRIPTOR' : _USER,
  '__module__' : 'eolymp.cognito.user_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.User)
  })
_sym_db.RegisterMessage(User)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
